@@ -1,14 +1,5 @@
-logPriorDensSN = function(N, particles, priorList){
- p = ncol(particles$xi)
- #
-# nu = particles$nu
- particlesStar = reparamSkew(N=N, particles=particles)
- #
-# gdls.list = priorList$gdls
-#  nuIndices = numeric(N)
-#  for(iN in 1:N){
-#   nuIndices[iN] = which(gdls.list == nu[iN])
-#  }
+logPriorDensSN = function(N, p, particles, priorList){
+ particlesStar = reparamSkew(N=N, p=p, particles=particles)
  logPriorDens = # 0 +   							               # xi
   - nSphereVolume(p, 1, LOG=T) - 0.5 * particlesStar$log.detOmega +	# delta
   (-(p+1)/2) * particlesStar$log.detSigma +		# Sigma
