@@ -1,24 +1,41 @@
-sampleGSN = function(y, N, particles, priorList){
+sampleGSN = function(y, X, N, particles, priorList){
 # Given the arguments, this function returns a population of MC draws for the values of the variable G, in the p-variate skew-t model.
  n = nrow(y)
  p = ncol(y)
-#
+ #
+ XFlag = !is.null(X)
+ if(XFlag){
+  k = ncol(X)
+  B = particles$B
+  RX = X[rep(1:n, times=N),,drop=F]
+ } else {
+  xi = particles$xi
+ }
+ #
  pmat.indices.w = triangleIndices(p, side='u', dgn=T, dataframe=T)
  n.pmat.indices.w = p * (p+1) / 2
- Ry = matrix(0, n*N, p)
- Rxi = matrix(0, n*N, p)
- Rpsi = matrix(0, n*N, p)
+ Ry = y[rep(1:n, times=N),,drop=F]
+ Rpsi = particles$psi[rep(1:N, each=n),]
+ RM = matrix(0, n*N, p) # xi or B'X
  for(icol in 1:p){
-  Ry[,icol] = rep(y[,icol], N)
-  Rxi[,icol] = rep(particles$xi[,icol], each=n)
-  Rpsi[,icol] = rep(particles$psi[,icol], each=n)
+  if(XFlag){
+   if(k==1){
+    RB = matrix(B[,icol,c(rep(1:N,each=n))], ncol=1)
+   } else {
+    RB = t(B[,icol,c(rep(1:N,each=n))])
+   }
+   # RB = t(B[,icol,c(rep(1:N,each=n))])
+   RM[,icol] = apply(RB*RX,1,sum)
+  } else {
+   RM[,icol] = xi[rep(1:N, each=n),icol]
+  }
  }
-# v = particles$v
-# sqrt.v = as.numeric(t(sqrt(v)))
+ # v = particles$v
+ # sqrt.v = as.numeric(t(sqrt(v)))
  z = particles$z
  abs.z = as.numeric(t(abs(z)))
-
- e = Ry - Rxi - matrix(rep(abs.z, p), ncol=p) * Rpsi
+ #
+ e = Ry - RM - matrix(rep(abs.z, p), ncol=p) * Rpsi
  eList = vector('list', p)
  for(ilist in 1:p){
   eList[[ilist]] = matrix(e[,ilist], N, n, byrow=T)
@@ -38,5 +55,6 @@ sampleGSN = function(y, N, particles, priorList){
   G[iN,] = as.numeric(G.iN)
   log.dG[iN] = diwish.mia3(G.iN, n+priorList$m, W.star.iN, LOG=TRUE)
  }
+
  return(list(values=G, log.dq=log.dG))
 }
