@@ -1,8 +1,8 @@
-samplexiST = function(y, N, particles, priorList){
+samplexiST = function(y, X, N, particles, priorList){
 # Given the arguments, this function returns a population of MC draws for the values of the variable Xi, in the p-variate skew-t model.
  n = nrow(y)
  p = ncol(y)
-#
+ #
  pmat.indices.wVEC = triangleIndices(p, side='u', dgn=T, dataframe=F)
  pmat.indices.wDF = triangleIndices(p, side='u', dgn=T, dataframe=T)
  n.pmat.indices.w = p * (p+1) / 2
@@ -32,9 +32,6 @@ samplexiST = function(y, N, particles, priorList){
   xi[iN,] = xi.iN
   log.dxi[iN] = dmnorm(as.numeric(xi.iN), mxi[iN,], vxi.iN, log=TRUE)
  }
-# Rxi = matrix(0, n*N, p)
-# for(icol in 1:p){
-#  Rxi[,icol] = rep(xi[,icol], each=n)
-# }
- return(list(values=xi, log.dq=log.dxi))# , repxi=Rxi))
+ #
+ return(list(values=xi, log.dq=log.dxi))
 }
